==> com.liferay.frontend.editor.tinymce.web-4.0.0.jar: META-INF/resources/_diffs/langs/ko_KR.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('ko_KR', {
	Cut: '\uc798\ub77c\ub0b4\uae30',
	'Heading 5': '\uc81c\ubaa9 5',
	'Header 2': '\uc81c\ubaa9 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'\ube0c\ub77c\uc6b0\uc838\uac00 \ud074\ub9bd\ubcf4\ub4dc \uc811\uadfc\uc744 \ud5c8\uc6a9\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. Ctrl+X/C/V \ud0a4\ub97c \uc774\uc6a9\ud574 \uc8fc\uc138\uc694.',
	'Heading 4': '\uc81c\ubaa9 4',
	Div: '\uad6c\ubd84',
	'Heading 2': '\uc81c\ubaa9 2',
	Paste: '\ubd99\uc5ec\ub123\uae30',
	Close: '\ub2eb\uae30',
	'Font Family': '\uae00\uaf34',
	Pre: 'Pre',
	'Align right': '\uc624\ub978\ucabd\uc815\ub82c',
	'New document': '\uc0c8 \ubb38\uc11c',
	Blockquote: '\uad6c\ud68d',
	'Numbered list': '\uc22b\uc790\ub9ac\uc2a4\ud2b8',
	'Heading 1': '\uc81c\ubaa9 1',
	Headings: '\uc81c\ubaa9',
	'Increase indent': '\ub4e4\uc5ec\uc4f0\uae30',
	Formats: '\ud3ec\ub9f7',
	Headers: '\uc2a4\ud0c0\uc77c',
	'Select all': '\uc804\uccb4\uc120\ud0dd',
	'Header 3': '\uc81c\ubaa9 3',
	Blocks: '\ube14\ub85d \uc124\uc815',
	Undo: '\uc2e4\ud589\ucde8\uc18c',
	Strikethrough: '\ucde8\uc18c\uc120',
	'Bullet list': '\uc810\ub9ac\uc2a4\ud2b8',
	'Header 1': '\uc81c\ubaa9 1',
	Superscript: '\uc717\ucca8\uc790',
	'Clear formatting': '\ud3ec\ub9f7\ucd08\uae30\ud654',
	'Font Sizes': '\ud3f0\ud2b8 \uc0ac\uc774\uc988',
	Subscript: '\uc544\ub798\ucca8\uc790',
	'Header 6': '\uc81c\ubaa9 6',
	Redo: '\ub2e4\uc2dc\uc2e4\ud589',
	Paragraph: '\ub2e8\ub77d',
	Ok: '\ud655\uc778',
	Bold: '\uad75\uac8c',
	Code: '\ucf54\ub4dc',
	Italic: '\uae30\uc6b8\uc784\uaf34',
	'Align center': '\uac00\uc6b4\ub370\uc815\ub82c',
	'Header 5': '\uc81c\ubaa9 5',
	'Heading 6': '\uc81c\ubaa9 6',
	'Heading 3': '\uc81c\ubaa9 3',
	'Decrease indent': '\ub0b4\uc5b4\uc4f0\uae30',
	'Header 4': '\uc81c\ubaa9 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'\uc2a4\ud0c0\uc77c\ubcf5\uc0ac \ub044\uae30. \uc774 \uc635\uc158\uc744 \ub044\uae30 \uc804\uc5d0\ub294 \ubcf5\uc0ac \uc2dc, \uc2a4\ud0c0\uc77c\uc774 \ubcf5\uc0ac\ub418\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4.',
	Underline: '\ubc11\uc904',
	Cancel: '\ucde8\uc18c',
	Justify: '\uc591\ucabd\uc815\ub82c',
	Inline: '\ub77c\uc778 \uc124\uc815',
	Copy: '\ubcf5\uc0ac\ud558\uae30',
	'Align left': '\uc67c\ucabd\uc815\ub82c',
	'Visual aids': '\uc2dc\uac01\uad50\uc7ac',
	'Lower Greek': '\uadf8\ub9ac\uc2a4\uc5b4 \uc18c\ubb38\uc790',
	Square: '\uc0ac\uac01',
	Default: '\uae30\ubcf8',
	'Lower Alpha': '\uc54c\ud30c\ubcb3 \uc18c\ubb38\uc790',
	Circle: '\uc6d0',
	Disc: '\uc6d0\ubc18',
	'Upper Alpha': '\uc54c\ud30c\ubcb3 \uc18c\ubb38\uc790',
	'Upper Roman': '\ub85c\ub9c8\uc790 \ub300\ubb38\uc790',
	'Lower Roman': '\ub85c\ub9c8\uc790 \uc18c\ubb38\uc790',
	Name: '\uc774\ub984',
	Anchor: '\uc575\ucee4',
	'You have unsaved changes are you sure you want to navigate away?':
		'\uc800\uc7a5\ud558\uc9c0 \uc54a\uc740 \uc815\ubcf4\uac00 \uc788\uc2b5\ub2c8\ub2e4. \uc774 \ud398\uc774\uc9c0\ub97c \ubc97\uc5b4\ub098\uc2dc\uaca0\uc2b5\ub2c8\uae4c?',
	'Restore last draft': '\ub9c8\uc9c0\ub9c9 \ucd08\uc548 \ubcf5\uc6d0',
	'Special character': '\ud2b9\uc218\ubb38\uc790',
	'Source code': '\uc18c\uc2a4\ucf54\ub4dc',
	Color: '\uc0c9',
	'Right to left': '\uc624\ub978\ucabd\uc5d0\uc11c \uc67c\ucabd',
	'Left to right': '\uc67c\ucabd\uc5d0\uc11c \uc624\ub978\ucabd',
	Emoticons: '\uc774\ubaa8\ud2f0\ucf58',
	Robots: '\ub85c\ubd07',
	'Document properties': '\ubb38\uc11c \uc18d\uc131',
	Title: '\uc81c\ubaa9',
	Keywords: '\ud0a4\uc6cc\ub4dc',
	Encoding: '\uc778\ucf54\ub529',
	Description: '\uc124\uba85',
	Author: '\uc800\uc790',
	Fullscreen: '\uc804\uccb4\ud654\uba74',
	'Horizontal line': '\uac00\ub85c',
	'Horizontal space': '\uc218\ud3c9 \uacf5\ubc31',
	'Insert/edit image': '\uc774\ubbf8\uc9c0 \uc0bd\uc785/\uc218\uc815',
	General: '\uc77c\ubc18',
	Advanced: '\uace0\uae09',
	Source: '\uc18c\uc2a4',
	Border: '\ud14c\ub450\ub9ac',
	'Constrain proportions': '\uc791\uc5c5 \uc81c\ud55c',
	'Vertical space': '\uc218\uc9c1 \uacf5\ubc31',
	'Image description': '\uc774\ubbf8\uc9c0 \uc124\uba85',
	Style: '\uc2a4\ud0c0\uc77c',
	Dimensions: '\ud06c\uae30',
	'Insert image': '\uc774\ubbf8\uc9c0 \uc0bd\uc785',
	'Insert date/time': '\ub0a0\uc9dc/\uc2dc\uac04\uc0bd\uc785',
	'Remove link': '\ub9c1\ud06c\uc0ad\uc81c',
	Url: '\uc8fc\uc18c',
	'Text to display': '\ubcf8\ubb38',
	Anchors: '\ucc45\uac08\ud53c',
	'Insert link': '\ub9c1\ud06c \uc0bd\uc785 ',
	'New window': '\uc0c8\ucc3d',
	None: '\uc5c6\uc74c',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'\ud604\uc7ac URL(\uc6f9\uc0ac\uc774\ud2b8 \uc8fc\uc18c)\ub97c \uc785\ub825\ud558\uc168\uc2b5\ub2c8\ub2e4. URL\uc5d0 \ub9c1\ud06c\ub97c \uac78\uae4c\uc694?',
	Target: '\ub300\uc0c1',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'\ud604\uc7ac E-mail(\uc774\uba54\uc77c)\uc8fc\uc18c\ub97c \uc785\ub825\ud558\uc168\uc2b5\ub2c8\ub2e4. \uc774\uba54\uc77c\uc5d0 \ub9c1\ud06c\ub97c \uac78\uae4c\uc694?',
	'Insert/edit link': '\ub9c1\ud06c \uc0bd\uc785/\uc218\uc815',
	'Insert/edit video': '\ube44\ub514\uc624 \uc0bd\uc785/\uc218\uc815',
	Poster: '\ud3ec\uc2a4\ud130',
	'Alternative source': '\ub300\uccb4 \uc18c\uc2a4',
	'Paste your embed code below:':
		'\uc544\ub798\uc5d0 \ucf54\ub4dc\ub97c \ubd99\uc5ec\ub123\uc73c\uc138\uc694:',
	'Insert video': '\ube44\ub514\uc624 \uc0bd\uc785',
	Embed: '\uc0bd\uc785',
	'Nonbreaking space': '\ub744\uc5b4\uc4f0\uae30',
	'Page break': '\ud398\uc774\uc9c0 \uad6c\ubd84\uc790',
	'Paste as text': '\ud14d\uc2a4\ud2b8\ub85c \ubd99\uc5ec\ub123\uae30',
	Preview: '\ubbf8\ub9ac\ubcf4\uae30',
	Print: '\ucd9c\ub825',
	Save: '\uc800\uc7a5',
	'Could not find the specified string.':
		'\ubb38\uc790\ub97c \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4.',
	Replace: '\uad50\uccb4',
	Next: '\ub2e4\uc74c',
	'Whole words': '\uc804\uccb4 \ub2e8\uc5b4',
	'Find and replace': '\ucc3e\uc544\uc11c \uad50\uccb4',
	'Replace with': '\uad50\uccb4',
	Find: '\ucc3e\uae30',
	'Replace all': '\uc804\uccb4 \uad50\uccb4',
	'Match case': '\ub300\uc18c\ubb38\uc790 \uc77c\uce58',
	Prev: '\uc774\uc804',
	Spellcheck: '\ubb38\ubc95\uccb4\ud06c',
	Finish: '\uc644\ub8cc',
	'Ignore all': '\uc804\uccb4\ubb34\uc2dc',
	Ignore: '\ubb34\uc2dc',
	'Add to Dictionary': '\uc0ac\uc804\uc5d0 \ucd94\uac00',
	'Insert row before': '\uc774\uc804\uc5d0 \ud589 \uc0bd\uc785',
	Rows: '\ud589',
	Height: '\ub192\uc774',
	'Paste row after': '\ub2e4\uc74c\uc5d0 \ud589 \ubd99\uc5ec\ub123\uae30',
	Alignment: '\uc815\ub82c',
	'Border color': '\ud14c\ub450\ub9ac \uc0c9',
	'Column group': '\uc5f4 \uadf8\ub8f9',
	Row: '\uc5f4',
	'Insert column before': '\uc774\uc804\uc5d0 \ud589 \uc0bd\uc785',
	'Split cell': '\uc140 \ub098\ub204\uae30',
	'Cell padding': '\uc140 \uc548\ucabd \uc5ec\ubc31',
	'Cell spacing': '\uc140 \uac04\uaca9',
	'Row type': '\ud589 \ud0c0\uc785',
	'Insert table': '\ud14c\uc774\ube14 \uc0bd\uc785',
	Body: '\ubc14\ub514',
	Caption: '\ucea1\uc158',
	Footer: '\ud478\ud130',
	'Delete row': '\ud589 \uc9c0\uc6b0\uae30',
	'Paste row before': '\uc774\uc804\uc5d0 \ud589 \ubd99\uc5ec\ub123\uae30',
	Scope: '\ubc94\uc704',
	'Delete table': '\ud14c\uc774\ube14 \uc0ad\uc81c',
	'H Align': '\uac00\ub85c \uc815\ub82c',
	Top: '\uc0c1\ub2e8',
	'Header cell': '\ud5e4\ub354 \uc140',
	Column: '\ud589',
	'Row group': '\ud589 \uadf8\ub8f9',
	Cell: '\uc140',
	Middle: '\uc911\uac04',
	'Cell type': '\uc140 \ud0c0\uc785',
	'Copy row': '\ud589 \ubcf5\uc0ac',
	'Row properties': '\ud589 \uc18d\uc131',
	'Table properties': '\ud14c\uc774\ube14 \uc18d\uc131',
	Bottom: '\ud558\ub2e8',
	'V Align': '\uc138\ub85c \uc815\ub82c',
	Header: '\ud5e4\ub354',
	Right: '\uc624\ub978\ucabd',
	'Insert column after': '\ub2e4\uc74c\uc5d0 \uc5f4 \uc0bd\uc785',
	Cols: '\uc5f4',
	'Insert row after': '\ub2e4\uc74c\uc5d0 \ud589 \uc0bd\uc785',
	Width: '\ub113\uc774',
	'Cell properties': '\uc140 \uc18d',
	Left: '\uc67c\ucabd',
	'Cut row': '\ud589 \uc798\ub77c\ub0b4\uae30',
	'Delete column': '\uc5f4 \uc9c0\uc6b0\uae30',
	Center: '\uac00\uc6b4\ub370',
	'Merge cells': '\uc140 \ud569\uce58\uae30',
	'Insert template': '\ud15c\ud50c\ub9bf \uc0bd\uc785',
	Templates: '\ud15c\ud50c\ub9bf',
	'Background color': '\ubc30\uacbd\uc0c9',
	'Custom...': '\uc9c1\uc811 \uc0c9\uae54 \uc9c0\uc815\ud558\uae30',
	'Custom color': '\uc9c1\uc811 \uc9c0\uc815\ud55c \uc0c9\uae54',
	'No color': '\uc0c9\uc0c1 \uc5c6\uc74c',
	'Text color': '\ubb38\uc790 \uc0c9\uae54',
	'Show blocks': '\ube14\ub7ed \ubcf4\uc5ec\uc8fc\uae30',
	'Show invisible characters':
		'\uc548\ubcf4\uc774\ub294 \ubb38\uc790 \ubcf4\uc774\uae30',
	'Words: {0}': '\ub2e8\uc5b4: {0}',
	Insert: '\uc0bd\uc785',
	File: '\ud30c\uc77c',
	Edit: '\uc218\uc815',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'\uc11c\uc2dd \uc788\ub294 \ud14d\uc2a4\ud2b8 \ud3b8\uc9d1\uae30 \uc785\ub2c8\ub2e4. ALT-F9\ub97c \ub204\ub974\uba74 \uba54\ub274, ALT-F10\ub97c \ub204\ub974\uba74 \ud234\ubc14, ALT-0\uc744 \ub204\ub974\uba74 \ub3c4\uc6c0\ub9d0\uc744 \ubcfc \uc218 \uc788\uc2b5\ub2c8\ub2e4.',
	Tools: '\ub3c4\uad6c',
	View: '\ubcf4\uae30',
	Table: '\ud14c\uc774\ube14',
	Format: '\ud3ec\ub9f7'
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/ko_KR.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('ko_KR', {
	'Cut': '\uc798\ub77c\ub0b4\uae30',
	'Heading 5': '\uc81c\ubaa9 5',
	'Header 2': '\uc81c\ubaa9 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'\ube0c\ub77c\uc6b0\uc838\uac00 \ud074\ub9bd\ubcf4\ub4dc \uc811\uadfc\uc744 \ud5c8\uc6a9\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. Ctrl+X/C/V \ud0a4\ub97c \uc774\uc6a9\ud574 \uc8fc\uc138\uc694.',
	'Heading 4': '\uc81c\ubaa9 4',
	'Div': '\uad6c\ubd84',
	'Heading 2': '\uc81c\ubaa9 2',
	'Paste': '\ubd99\uc5ec\ub123\uae30',
	'Close': '\ub2eb\uae30',
	'Font Family': '\uae00\uaf34',
	'Pre': 'Pre',
	'Align right': '\uc624\ub978\ucabd\uc815\ub82c',
	'New document': '\uc0c8 \ubb38\uc11c',
	'Blockquote': '\uad6c\ud68d',
	'Numbered list': '\uc22b\uc790\ub9ac\uc2a4\ud2b8',
	'Heading 1': '\uc81c\ubaa9 1',
	'Headings': '\uc81c\ubaa9',
	'Increase indent': '\ub4e4\uc5ec\uc4f0\uae30',
	'Formats': '\ud3ec\ub9f7',
	'Headers': '\uc2a4\ud0c0\uc77c',
	'Select all': '\uc804\uccb4\uc120\ud0dd',
	'Header 3': '\uc81c\ubaa9 3',
	'Blocks': '\ube14\ub85d \uc124\uc815',
	'Undo': '\uc2e4\ud589\ucde8\uc18c',
	'Strikethrough': '\ucde8\uc18c\uc120',
	'Bullet list': '\uc810\ub9ac\uc2a4\ud2b8',
	'Header 1': '\uc81c\ubaa9 1',
	'Superscript': '\uc717\ucca8\uc790',
	'Clear formatting': '\ud3ec\ub9f7\ucd08\uae30\ud654',
	'Font Sizes': '\ud3f0\ud2b8 \uc0ac\uc774\uc988',
	'Subscript': '\uc544\ub798\ucca8\uc790',
	'Header 6': '\uc81c\ubaa9 6',
	'Redo': '\ub2e4\uc2dc\uc2e4\ud589',
	'Paragraph': '\ub2e8\ub77d',
	'Ok': '\ud655\uc778',
	'Bold': '\uad75\uac8c',
	'Code': '\ucf54\ub4dc',
	'Italic': '\uae30\uc6b8\uc784\uaf34',
	'Align center': '\uac00\uc6b4\ub370\uc815\ub82c',
	'Header 5': '\uc81c\ubaa9 5',
	'Heading 6': '\uc81c\ubaa9 6',
	'Heading 3': '\uc81c\ubaa9 3',
	'Decrease indent': '\ub0b4\uc5b4\uc4f0\uae30',
	'Header 4': '\uc81c\ubaa9 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'\uc2a4\ud0c0\uc77c\ubcf5\uc0ac \ub044\uae30. \uc774 \uc635\uc158\uc744 \ub044\uae30 \uc804\uc5d0\ub294 \ubcf5\uc0ac \uc2dc, \uc2a4\ud0c0\uc77c\uc774 \ubcf5\uc0ac\ub418\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4.',
	'Underline': '\ubc11\uc904',
	'Cancel': '\ucde8\uc18c',
	'Justify': '\uc591\ucabd\uc815\ub82c',
	'Inline': '\ub77c\uc778 \uc124\uc815',
	'Copy': '\ubcf5\uc0ac\ud558\uae30',
	'Align left': '\uc67c\ucabd\uc815\ub82c',
	'Visual aids': '\uc2dc\uac01\uad50\uc7ac',
	'Lower Greek': '\uadf8\ub9ac\uc2a4\uc5b4 \uc18c\ubb38\uc790',
	'Square': '\uc0ac\uac01',
	'Default': '\uae30\ubcf8',
	'Lower Alpha': '\uc54c\ud30c\ubcb3 \uc18c\ubb38\uc790',
	'Circle': '\uc6d0',
	'Disc': '\uc6d0\ubc18',
	'Upper Alpha': '\uc54c\ud30c\ubcb3 \uc18c\ubb38\uc790',
	'Upper Roman': '\ub85c\ub9c8\uc790 \ub300\ubb38\uc790',
	'Lower Roman': '\ub85c\ub9c8\uc790 \uc18c\ubb38\uc790',
	'Name': '\uc774\ub984',
	'Anchor': '\uc575\ucee4',
	'You have unsaved changes are you sure you want to navigate away?':
		'\uc800\uc7a5\ud558\uc9c0 \uc54a\uc740 \uc815\ubcf4\uac00 \uc788\uc2b5\ub2c8\ub2e4. \uc774 \ud398\uc774\uc9c0\ub97c \ubc97\uc5b4\ub098\uc2dc\uaca0\uc2b5\ub2c8\uae4c?',
	'Restore last draft': '\ub9c8\uc9c0\ub9c9 \ucd08\uc548 \ubcf5\uc6d0',
	'Special character': '\ud2b9\uc218\ubb38\uc790',
	'Source code': '\uc18c\uc2a4\ucf54\ub4dc',
	'Color': '\uc0c9',
	'Right to left': '\uc624\ub978\ucabd\uc5d0\uc11c \uc67c\ucabd',
	'Left to right': '\uc67c\ucabd\uc5d0\uc11c \uc624\ub978\ucabd',
	'Emoticons': '\uc774\ubaa8\ud2f0\ucf58',
	'Robots': '\ub85c\ubd07',
	'Document properties': '\ubb38\uc11c \uc18d\uc131',
	'Title': '\uc81c\ubaa9',
	'Keywords': '\ud0a4\uc6cc\ub4dc',
	'Encoding': '\uc778\ucf54\ub529',
	'Description': '\uc124\uba85',
	'Author': '\uc800\uc790',
	'Fullscreen': '\uc804\uccb4\ud654\uba74',
	'Horizontal line': '\uac00\ub85c',
	'Horizontal space': '\uc218\ud3c9 \uacf5\ubc31',
	'Insert/edit image': '\uc774\ubbf8\uc9c0 \uc0bd\uc785/\uc218\uc815',
	'General': '\uc77c\ubc18',
	'Advanced': '\uace0\uae09',
	'Source': '\uc18c\uc2a4',
	'Border': '\ud14c\ub450\ub9ac',
	'Constrain proportions': '\uc791\uc5c5 \uc81c\ud55c',
	'Vertical space': '\uc218\uc9c1 \uacf5\ubc31',
	'Image description': '\uc774\ubbf8\uc9c0 \uc124\uba85',
	'Style': '\uc2a4\ud0c0\uc77c',
	'Dimensions': '\ud06c\uae30',
	'Insert image': '\uc774\ubbf8\uc9c0 \uc0bd\uc785',
	'Insert date/time': '\ub0a0\uc9dc/\uc2dc\uac04\uc0bd\uc785',
	'Remove link': '\ub9c1\ud06c\uc0ad\uc81c',
	'Url': '\uc8fc\uc18c',
	'Text to display': '\ubcf8\ubb38',
	'Anchors': '\ucc45\uac08\ud53c',
	'Insert link': '\ub9c1\ud06c \uc0bd\uc785 ',
	'New window': '\uc0c8\ucc3d',
	'None': '\uc5c6\uc74c',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'\ud604\uc7ac URL(\uc6f9\uc0ac\uc774\ud2b8 \uc8fc\uc18c)\ub97c \uc785\ub825\ud558\uc168\uc2b5\ub2c8\ub2e4. URL\uc5d0 \ub9c1\ud06c\ub97c \uac78\uae4c\uc694?',
	'Target': '\ub300\uc0c1',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'\ud604\uc7ac E-mail(\uc774\uba54\uc77c)\uc8fc\uc18c\ub97c \uc785\ub825\ud558\uc168\uc2b5\ub2c8\ub2e4. \uc774\uba54\uc77c\uc5d0 \ub9c1\ud06c\ub97c \uac78\uae4c\uc694?',
	'Insert/edit link': '\ub9c1\ud06c \uc0bd\uc785/\uc218\uc815',
	'Insert/edit video': '\ube44\ub514\uc624 \uc0bd\uc785/\uc218\uc815',
	'Poster': '\ud3ec\uc2a4\ud130',
	'Alternative source': '\ub300\uccb4 \uc18c\uc2a4',
	'Paste your embed code below:':
		'\uc544\ub798\uc5d0 \ucf54\ub4dc\ub97c \ubd99\uc5ec\ub123\uc73c\uc138\uc694:',
	'Insert video': '\ube44\ub514\uc624 \uc0bd\uc785',
	'Embed': '\uc0bd\uc785',
	'Nonbreaking space': '\ub744\uc5b4\uc4f0\uae30',
	'Page break': '\ud398\uc774\uc9c0 \uad6c\ubd84\uc790',
	'Paste as text': '\ud14d\uc2a4\ud2b8\ub85c \ubd99\uc5ec\ub123\uae30',
	'Preview': '\ubbf8\ub9ac\ubcf4\uae30',
	'Print': '\ucd9c\ub825',
	'Save': '\uc800\uc7a5',
	'Could not find the specified string.':
		'\ubb38\uc790\ub97c \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4.',
	'Replace': '\uad50\uccb4',
	'Next': '\ub2e4\uc74c',
	'Whole words': '\uc804\uccb4 \ub2e8\uc5b4',
	'Find and replace': '\ucc3e\uc544\uc11c \uad50\uccb4',
	'Replace with': '\uad50\uccb4',
	'Find': '\ucc3e\uae30',
	'Replace all': '\uc804\uccb4 \uad50\uccb4',
	'Match case': '\ub300\uc18c\ubb38\uc790 \uc77c\uce58',
	'Prev': '\uc774\uc804',
	'Spellcheck': '\ubb38\ubc95\uccb4\ud06c',
	'Finish': '\uc644\ub8cc',
	'Ignore all': '\uc804\uccb4\ubb34\uc2dc',
	'Ignore': '\ubb34\uc2dc',
	'Add to Dictionary': '\uc0ac\uc804\uc5d0 \ucd94\uac00',
	'Insert row before': '\uc774\uc804\uc5d0 \ud589 \uc0bd\uc785',
	'Rows': '\ud589',
	'Height': '\ub192\uc774',
	'Paste row after': '\ub2e4\uc74c\uc5d0 \ud589 \ubd99\uc5ec\ub123\uae30',
	'Alignment': '\uc815\ub82c',
	'Border color': '\ud14c\ub450\ub9ac \uc0c9',
	'Column group': '\uc5f4 \uadf8\ub8f9',
	'Row': '\uc5f4',
	'Insert column before': '\uc774\uc804\uc5d0 \ud589 \uc0bd\uc785',
	'Split cell': '\uc140 \ub098\ub204\uae30',
	'Cell padding': '\uc140 \uc548\ucabd \uc5ec\ubc31',
	'Cell spacing': '\uc140 \uac04\uaca9',
	'Row type': '\ud589 \ud0c0\uc785',
	'Insert table': '\ud14c\uc774\ube14 \uc0bd\uc785',
	'Body': '\ubc14\ub514',
	'Caption': '\ucea1\uc158',
	'Footer': '\ud478\ud130',
	'Delete row': '\ud589 \uc9c0\uc6b0\uae30',
	'Paste row before': '\uc774\uc804\uc5d0 \ud589 \ubd99\uc5ec\ub123\uae30',
	'Scope': '\ubc94\uc704',
	'Delete table': '\ud14c\uc774\ube14 \uc0ad\uc81c',
	'H Align': '\uac00\ub85c \uc815\ub82c',
	'Top': '\uc0c1\ub2e8',
	'Header cell': '\ud5e4\ub354 \uc140',
	'Column': '\ud589',
	'Row group': '\ud589 \uadf8\ub8f9',
	'Cell': '\uc140',
	'Middle': '\uc911\uac04',
	'Cell type': '\uc140 \ud0c0\uc785',
	'Copy row': '\ud589 \ubcf5\uc0ac',
	'Row properties': '\ud589 \uc18d\uc131',
	'Table properties': '\ud14c\uc774\ube14 \uc18d\uc131',
	'Bottom': '\ud558\ub2e8',
	'V Align': '\uc138\ub85c \uc815\ub82c',
	'Header': '\ud5e4\ub354',
	'Right': '\uc624\ub978\ucabd',
	'Insert column after': '\ub2e4\uc74c\uc5d0 \uc5f4 \uc0bd\uc785',
	'Cols': '\uc5f4',
	'Insert row after': '\ub2e4\uc74c\uc5d0 \ud589 \uc0bd\uc785',
	'Width': '\ub113\uc774',
	'Cell properties': '\uc140 \uc18d',
	'Left': '\uc67c\ucabd',
	'Cut row': '\ud589 \uc798\ub77c\ub0b4\uae30',
	'Delete column': '\uc5f4 \uc9c0\uc6b0\uae30',
	'Center': '\uac00\uc6b4\ub370',
	'Merge cells': '\uc140 \ud569\uce58\uae30',
	'Insert template': '\ud15c\ud50c\ub9bf \uc0bd\uc785',
	'Templates': '\ud15c\ud50c\ub9bf',
	'Background color': '\ubc30\uacbd\uc0c9',
	'Custom...': '\uc9c1\uc811 \uc0c9\uae54 \uc9c0\uc815\ud558\uae30',
	'Custom color': '\uc9c1\uc811 \uc9c0\uc815\ud55c \uc0c9\uae54',
	'No color': '\uc0c9\uc0c1 \uc5c6\uc74c',
	'Text color': '\ubb38\uc790 \uc0c9\uae54',
	'Show blocks': '\ube14\ub7ed \ubcf4\uc5ec\uc8fc\uae30',
	'Show invisible characters':
		'\uc548\ubcf4\uc774\ub294 \ubb38\uc790 \ubcf4\uc774\uae30',
	'Words: {0}': '\ub2e8\uc5b4: {0}',
	'Insert': '\uc0bd\uc785',
	'File': '\ud30c\uc77c',
	'Edit': '\uc218\uc815',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'\uc11c\uc2dd \uc788\ub294 \ud14d\uc2a4\ud2b8 \ud3b8\uc9d1\uae30 \uc785\ub2c8\ub2e4. ALT-F9\ub97c \ub204\ub974\uba74 \uba54\ub274, ALT-F10\ub97c \ub204\ub974\uba74 \ud234\ubc14, ALT-0\uc744 \ub204\ub974\uba74 \ub3c4\uc6c0\ub9d0\uc744 \ubcfc \uc218 \uc788\uc2b5\ub2c8\ub2e4.',
	'Tools': '\ub3c4\uad6c',
	'View': '\ubcf4\uae30',
	'Table': '\ud14c\uc774\ube14',
	'Format': '\ud3ec\ub9f7',
});
